@@ -23,6 +23,7 @@ import os
 import re
 import uuid
 import warnings
+from io import BytesIO
 
 import botocore
 import botocore.auth
@@ -35,7 +36,6 @@ from botocore.compat import (
     get_md5,
     json,
     quote,
-    six,
     unquote,
     unquote_str,
     urlsplit,
@@ -65,11 +65,11 @@ from botocore.utils import (
 )
 
 # Keep these imported.  There's pre-existing code that uses them.
-from botocore import retryhandler # noqa
-from botocore import translate # noqa
-from botocore.compat import MD5_AVAILABLE # noqa
-from botocore.exceptions import MissingServiceIdError # noqa
-from botocore.utils import hyphenize_service_id # noqa
+from botocore import retryhandler  # noqa
+from botocore import translate  # noqa
+from botocore.compat import MD5_AVAILABLE  # noqa
+from botocore.exceptions import MissingServiceIdError  # noqa
+from botocore.utils import hyphenize_service_id  # noqa
 
 
 logger = logging.getLogger(__name__)
@@ -93,9 +93,7 @@ _OUTPOST_ARN = (
 VALID_S3_ARN = re.compile('|'.join([_ACCESSPOINT_ARN, _OUTPOST_ARN]))
 VERSION_ID_SUFFIX = re.compile(r'\?versionId=[^\s]+$')
 
-SERVICE_NAME_ALIASES = {
-    'runtime.sagemaker': 'sagemaker-runtime'
-}
+SERVICE_NAME_ALIASES = {'runtime.sagemaker': 'sagemaker-runtime'}
 
 
 def handle_service_name_alias(service_name, **kwargs):
@@ -149,9 +147,12 @@ def check_for_200_error(response, **kwargs):
         return
     http_response, parsed = response
     if _looks_like_special_case_error(http_response):
-        logger.debug("Error found for response with 200 status code, "
-                     "errors: %s, changing status code to "
-                     "500.", parsed)
+        logger.debug(
+            "Error found for response with 200 status code, "
+            "errors: %s, changing status code to "
+            "500.",
+            parsed,
+        )
         http_response.status_code = 500
 
 
@@ -159,8 +160,8 @@ def _looks_like_special_case_error(http_response):
     if http_response.status_code == 200:
         try:
             parser = ETree.XMLParser(
-                target=ETree.TreeBuilder(),
-                encoding='utf-8')
+                target=ETree.TreeBuilder(), encoding='utf-8'
+            )
             parser.feed(http_response.content)
             root = parser.close()
         except XMLParseError:
@@ -174,7 +175,7 @@ def _looks_like_special_case_error(http_response):
 
 
 def set_operation_specific_signer(context, signing_name, **kwargs):
-    """ Choose the operation-specific signer.
+    """Choose the operation-specific signer.
 
     Individual operations may have a different auth type than the service as a
     whole. This will most often manifest as operations that should not be
@@ -196,10 +197,7 @@ def set_operation_specific_signer(context, signing_name, **kwargs):
     if auth_type == 'v4a':
         # If sigv4a is chosen, we must add additional
         # signing config for global signature.
-        signing = {
-            'region': '*',
-            'signing_name': signing_name
-        }
+        signing = {'region': '*', 'signing_name': signing_name}
         if 'signing' in context:
             context['signing'].update(signing)
         else:
@@ -228,8 +226,9 @@ def decode_console_output(parsed, **kwargs):
             # We're using 'replace' for errors because it is
             # possible that console output contains non string
             # chars we can't utf-8 decode.
-            value = base64.b64decode(six.b(parsed['Output'])).decode(
-                'utf-8', 'replace')
+            value = base64.b64decode(
+                bytes(parsed['Output'], 'latin-1')
+            ).decode('utf-8', 'replace')
             parsed['Output'] = value
         except (ValueError, TypeError, AttributeError):
             logger.debug('Error decoding base64', exc_info=True)
@@ -239,8 +238,10 @@ def generate_idempotent_uuid(params, model, **kwargs):
     for name in model.idempotent_members:
         if name not in params:
             params[name] = str(uuid.uuid4())
-            logger.debug("injecting idempotency token (%s) into param '%s'." %
-                         (params[name], name))
+            logger.debug(
+                "injecting idempotency token (%s) into param '%s'."
+                % (params[name], name)
+            )
 
 
 def decode_quoted_jsondoc(value):
@@ -255,7 +256,8 @@ def json_decode_template_body(parsed, **kwargs):
     if 'TemplateBody' in parsed:
         try:
             value = json.loads(
-                parsed['TemplateBody'], object_pairs_hook=OrderedDict)
+                parsed['TemplateBody'], object_pairs_hook=OrderedDict
+            )
             parsed['TemplateBody'] = value
         except (ValueError, TypeError):
             logger.debug('error loading JSON', exc_info=True)
@@ -267,9 +269,10 @@ def validate_bucket_name(params, **kwargs):
     bucket = params['Bucket']
     if not VALID_BUCKET.search(bucket) and not VALID_S3_ARN.search(bucket):
         error_msg = (
-            'Invalid bucket name "%s": Bucket name must match '
-            'the regex "%s" or be an ARN matching the regex "%s"' % (
-                bucket, VALID_BUCKET.pattern, VALID_S3_ARN.pattern))
+            f'Invalid bucket name "{bucket}": Bucket name must match '
+            f'the regex "{VALID_BUCKET.pattern}" or be an ARN matching '
+            f'the regex "{VALID_S3_ARN.pattern}"'
+        )
         raise ParamValidationError(report=error_msg)
 
 
@@ -300,10 +303,11 @@ def _sse_md5(params, sse_member_prefix='SSECustomer'):
     sse_key_member = sse_member_prefix + 'Key'
     sse_md5_member = sse_member_prefix + 'KeyMD5'
     key_as_bytes = params[sse_key_member]
-    if isinstance(key_as_bytes, six.text_type):
+    if isinstance(key_as_bytes, str):
         key_as_bytes = key_as_bytes.encode('utf-8')
-    key_md5_str = base64.b64encode(
-        get_md5(key_as_bytes).digest()).decode('utf-8')
+    key_md5_str = base64.b64encode(get_md5(key_as_bytes).digest()).decode(
+        'utf-8'
+    )
     key_b64_encoded = base64.b64encode(key_as_bytes).decode('utf-8')
     params[sse_key_member] = key_b64_encoded
     params[sse_md5_member] = key_md5_str
@@ -336,7 +340,7 @@ def add_expect_header(model, params, **kwargs):
             params['headers']['Expect'] = '100-continue'
 
 
-class DeprecatedServiceDocumenter(object):
+class DeprecatedServiceDocumenter:
     def __init__(self, replacement_service_name):
         self._replacement_service_name = replacement_service_name
 
@@ -357,8 +361,10 @@ def document_copy_source_form(section, event_name, **kwargs):
         param_line = parent.get_section('CopySource')
         value_portion = param_line.get_section('member-value')
         value_portion.clear_text()
-        value_portion.write("'string' or {'Bucket': 'string', "
-                            "'Key': 'string', 'VersionId': 'string'}")
+        value_portion.write(
+            "'string' or {'Bucket': 'string', "
+            "'Key': 'string', 'VersionId': 'string'}"
+        )
     elif 'request-params' in event_name:
         param_section = section.get_section('CopySource')
         type_section = param_section.get_section('param-type')
@@ -407,7 +413,7 @@ def handle_copy_source_param(params, **kwargs):
         # param validator take care of this.  It will
         # give a better error message.
         return
-    if isinstance(source, six.string_types):
+    if isinstance(source, str):
         params['CopySource'] = _quote_source_header(source)
     elif isinstance(source, dict):
         params['CopySource'] = _quote_source_header_from_dict(source)
@@ -419,12 +425,13 @@ def _quote_source_header_from_dict(source_dict):
         key = source_dict['Key']
         version_id = source_dict.get('VersionId')
         if VALID_S3_ARN.search(bucket):
-            final = '%s/object/%s' % (bucket, key)
+            final = f'{bucket}/object/{key}'
         else:
-            final = '%s/%s' % (bucket, key)
+            final = f'{bucket}/{key}'
     except KeyError as e:
         raise ParamValidationError(
-            report='Missing required parameter: %s' % str(e))
+            report=f'Missing required parameter: {str(e)}'
+        )
     final = percent_encode(final, safe=SAFE_CHARS + '/')
     if version_id is not None:
         final += '?versionId=%s' % version_id
@@ -436,12 +443,13 @@ def _quote_source_header(value):
     if result is None:
         return percent_encode(value, safe=SAFE_CHARS + '/')
     else:
-        first, version_id = value[:result.start()], value[result.start():]
+        first, version_id = value[: result.start()], value[result.start() :]
         return percent_encode(first, safe=SAFE_CHARS + '/') + version_id
 
 
-def _get_cross_region_presigned_url(request_signer, request_dict, model,
-                                    source_region, destination_region):
+def _get_cross_region_presigned_url(
+    request_signer, request_dict, model, source_region, destination_region
+):
     # The better way to do this is to actually get the
     # endpoint_resolver and get the endpoint_url given the
     # source region.  In this specific case, we know that
@@ -453,12 +461,13 @@ def _get_cross_region_presigned_url(request_signer, request_dict, model,
     request_dict_copy = copy.deepcopy(request_dict)
     request_dict_copy['body']['DestinationRegion'] = destination_region
     request_dict_copy['url'] = request_dict['url'].replace(
-        destination_region, source_region)
+        destination_region, source_region
+    )
     request_dict_copy['method'] = 'GET'
     request_dict_copy['headers'] = {}
     return request_signer.generate_presigned_url(
-        request_dict_copy, region_name=source_region,
-        operation_name=model.name)
+        request_dict_copy, region_name=source_region, operation_name=model.name
+    )
 
 
 def _get_presigned_url_source_and_destination_regions(request_signer, params):
@@ -473,9 +482,11 @@ def inject_presigned_url_ec2(params, request_signer, model, **kwargs):
     if 'PresignedUrl' in params['body']:
         return
     src, dest = _get_presigned_url_source_and_destination_regions(
-        request_signer, params['body'])
+        request_signer, params['body']
+    )
     url = _get_cross_region_presigned_url(
-        request_signer, params, model, src, dest)
+        request_signer, params, model, src, dest
+    )
     params['body']['PresignedUrl'] = url
     # EC2 Requires that the destination region be sent over the wire in
     # addition to the source region.
@@ -490,7 +501,8 @@ def inject_presigned_url_rds(params, request_signer, model, **kwargs):
         return
 
     src, dest = _get_presigned_url_source_and_destination_regions(
-        request_signer, params['body'])
+        request_signer, params['body']
+    )
 
     # Since SourceRegion isn't actually modeled for RDS, it needs to be
     # removed from the request params before we send the actual request.
@@ -500,7 +512,8 @@ def inject_presigned_url_rds(params, request_signer, model, **kwargs):
         return
 
     url = _get_cross_region_presigned_url(
-        request_signer, params, model, src, dest)
+        request_signer, params, model, src, dest
+    )
     params['body']['PreSignedUrl'] = url
 
 
@@ -522,11 +535,14 @@ def _decode_policy_types(parsed, shape):
     shape_name = 'policyDocumentType'
     if shape.type_name == 'structure':
         for member_name, member_shape in shape.members.items():
-            if member_shape.type_name == 'string' and \
-                    member_shape.name == shape_name and \
-                    member_name in parsed:
+            if (
+                member_shape.type_name == 'string'
+                and member_shape.name == shape_name
+                and member_name in parsed
+            ):
                 parsed[member_name] = decode_quoted_jsondoc(
-                    parsed[member_name])
+                    parsed[member_name]
+                )
             elif member_name in parsed:
                 _decode_policy_types(parsed[member_name], member_shape)
     if shape.type_name == 'list':
@@ -544,9 +560,7 @@ def parse_get_bucket_location(parsed, http_response, **kwargs):
     if http_response.raw is None:
         return
     response_body = http_response.content
-    parser = ETree.XMLParser(
-        target=ETree.TreeBuilder(),
-        encoding='utf-8')
+    parser = ETree.XMLParser(target=ETree.TreeBuilder(), encoding='utf-8')
     parser.feed(response_body)
     root = parser.close()
     region = root.text
@@ -555,17 +569,20 @@ def parse_get_bucket_location(parsed, http_response, **kwargs):
 
 def base64_encode_user_data(params, **kwargs):
     if 'UserData' in params:
-        if isinstance(params['UserData'], six.text_type):
+        if isinstance(params['UserData'], str):
             # Encode it to bytes if it is text.
             params['UserData'] = params['UserData'].encode('utf-8')
-        params['UserData'] = base64.b64encode(
-            params['UserData']).decode('utf-8')
+        params['UserData'] = base64.b64encode(params['UserData']).decode(
+            'utf-8'
+        )
 
 
 def document_base64_encoding(param):
-    description = ('**This value will be base64 encoded automatically. Do '
-                   'not base64 encode this value prior to performing the '
-                   'operation.**')
+    description = (
+        '**This value will be base64 encoded automatically. Do '
+        'not base64 encode this value prior to performing the '
+        'operation.**'
+    )
     append = AppendParamDocumentation(param, description)
     return append.append_documentation
 
@@ -598,8 +615,7 @@ def validate_ascii_metadata(params, **kwargs):
                 'for key "%s", value: "%s".  \nS3 metadata can only '
                 'contain ASCII characters. ' % (key, value)
             )
-            raise ParamValidationError(
-                report=error_msg)
+            raise ParamValidationError(report=error_msg)
 
 
 def fix_route53_ids(params, model, **kwargs):
@@ -613,8 +629,11 @@ def fix_route53_ids(params, model, **kwargs):
     if not input_shape or not hasattr(input_shape, 'members'):
         return
 
-    members = [name for (name, shape) in input_shape.members.items()
-               if shape.name in ['ResourceId', 'DelegationSetId']]
+    members = [
+        name
+        for (name, shape) in input_shape.members.items()
+        if shape.name in ['ResourceId', 'DelegationSetId', 'ChangeId']
+    ]
 
     for name in members:
         if name in params:
@@ -635,7 +654,8 @@ def inject_account_id(params, **kwargs):
 def add_glacier_version(model, params, **kwargs):
     request_dict = params
     request_dict['headers']['x-amz-glacier-version'] = model.metadata[
-        'apiVersion']
+        'apiVersion'
+    ]
 
 
 def add_accept_header(model, params, **kwargs):
@@ -659,17 +679,18 @@ def add_glacier_checksums(params, **kwargs):
     request_dict = params
     headers = request_dict['headers']
     body = request_dict['body']
-    if isinstance(body, six.binary_type):
+    if isinstance(body, bytes):
         # If the user provided a bytes type instead of a file
         # like object, we're temporarily create a BytesIO object
         # so we can use the util functions to calculate the
         # checksums which assume file like objects.  Note that
         # we're not actually changing the body in the request_dict.
-        body = six.BytesIO(body)
+        body = BytesIO(body)
     starting_position = body.tell()
     if 'x-amz-content-sha256' not in headers:
         headers['x-amz-content-sha256'] = utils.calculate_sha256(
-            body, as_hex=True)
+            body, as_hex=True
+        )
     body.seek(starting_position)
     if 'x-amz-sha256-tree-hash' not in headers:
         headers['x-amz-sha256-tree-hash'] = utils.calculate_tree_hash(body)
@@ -693,7 +714,9 @@ def document_glacier_tree_hash_checksum():
     return AppendParamDocumentation('checksum', doc).append_documentation
 
 
-def document_cloudformation_get_template_return_type(section, event_name, **kwargs):
+def document_cloudformation_get_template_return_type(
+    section, event_name, **kwargs
+):
     if 'response-params' in event_name:
         template_body_section = section.get_section('TemplateBody')
         type_section = template_body_section.get_section('param-type')
@@ -713,6 +736,7 @@ def switch_host_machinelearning(request, **kwargs):
 
 def check_openssl_supports_tls_version_1_2(**kwargs):
     import ssl
+
     try:
         openssl_version_tuple = ssl.OPENSSL_VERSION_INFO
         if openssl_version_tuple < (1, 0, 1):
@@ -721,7 +745,7 @@ def check_openssl_supports_tls_version_1_2(**kwargs):
                 'support TLS 1.2, which is required for use of iot-data. '
                 'Please use python installed with openssl version 1.0.1 or '
                 'higher.' % (ssl.OPENSSL_VERSION),
-                UnsupportedTLSVersionWarning
+                UnsupportedTLSVersionWarning,
             )
     # We cannot check the openssl version on python2.6, so we should just
     # pass on this conveniency check.
@@ -759,7 +783,7 @@ def decode_list_object(parsed, context, **kwargs):
         top_level_keys=['Delimiter', 'Marker', 'NextMarker'],
         nested_keys=[('Contents', 'Key'), ('CommonPrefixes', 'Prefix')],
         parsed=parsed,
-        context=context
+        context=context,
     )
 
 
@@ -772,7 +796,7 @@ def decode_list_object_v2(parsed, context, **kwargs):
         top_level_keys=['Delimiter', 'Prefix', 'StartAfter'],
         nested_keys=[('Contents', 'Key'), ('CommonPrefixes', 'Prefix')],
         parsed=parsed,
-        context=context
+        context=context,
     )
 
 
@@ -794,12 +818,14 @@ def decode_list_object_versions(parsed, context, **kwargs):
             ('CommonPrefixes', 'Prefix'),
         ],
         parsed=parsed,
-        context=context
+        context=context,
     )
 
 
 def _decode_list_object(top_level_keys, nested_keys, parsed, context):
-    if parsed.get('EncodingType') == 'url' and context.get('encoding_type_auto_set'):
+    if parsed.get('EncodingType') == 'url' and context.get(
+        'encoding_type_auto_set'
+    ):
         # URL decode top-level keys in the response if present.
         for key in top_level_keys:
             if key in parsed:
@@ -813,10 +839,10 @@ def _decode_list_object(top_level_keys, nested_keys, parsed, context):
 
 def convert_body_to_file_like_object(params, **kwargs):
     if 'Body' in params:
-        if isinstance(params['Body'], six.string_types):
-            params['Body'] = six.BytesIO(ensure_bytes(params['Body']))
-        elif isinstance(params['Body'], six.binary_type):
-            params['Body'] = six.BytesIO(params['Body'])
+        if isinstance(params['Body'], str):
+            params['Body'] = BytesIO(ensure_bytes(params['Body']))
+        elif isinstance(params['Body'], bytes):
+            params['Body'] = BytesIO(params['Body'])
 
 
 def _add_parameter_aliases(handler_list):
@@ -828,7 +854,7 @@ def _add_parameter_aliases(handler_list):
     aliases = {
         'ec2.*.Filter': 'Filters',
         'logs.CreateExportTask.from': 'fromTime',
-        'cloudsearchdomain.Search.return': 'returnFields'
+        'cloudsearchdomain.Search.return': 'returnFields',
     }
 
     for original, new_name in aliases.items():
@@ -842,16 +868,17 @@ def _add_parameter_aliases(handler_list):
         parameter_build_event_handler_tuple = (
             'before-parameter-build.' + event_portion,
             parameter_alias.alias_parameter_in_call,
-            REGISTER_FIRST
+            REGISTER_FIRST,
         )
         docs_event_handler_tuple = (
             'docs.*.' + event_portion + '.complete-section',
-            parameter_alias.alias_parameter_in_documentation)
+            parameter_alias.alias_parameter_in_documentation,
+        )
         handler_list.append(parameter_build_event_handler_tuple)
         handler_list.append(docs_event_handler_tuple)
 
 
-class ParameterAlias(object):
+class ParameterAlias:
     def __init__(self, original_name, alias_name):
         self._original_name = original_name
         self._alias_name = alias_name
@@ -866,7 +893,7 @@ class ParameterAlias(object):
                         raise AliasConflictParameterError(
                             original=self._original_name,
                             alias=self._alias_name,
-                            operation=model.name
+                            operation=model.name,
                         )
                     # Remove the alias parameter value and use the old name
                     # instead.
@@ -895,14 +922,15 @@ class ParameterAlias(object):
     def _replace_content(self, section):
         content = section.getvalue().decode('utf-8')
         updated_content = content.replace(
-            self._original_name, self._alias_name)
+            self._original_name, self._alias_name
+        )
         section.clear_text()
         section.write(updated_content)
 
 
-class ClientMethodAlias(object):
+class ClientMethodAlias:
     def __init__(self, actual_name):
-        """ Aliases a non-extant method to an existing method.
+        """Aliases a non-extant method to an existing method.
 
         :param actual_name: The name of the method that actually exists on
             the client.
@@ -914,9 +942,9 @@ class ClientMethodAlias(object):
 
 
 # TODO: Remove this class as it is no longer used
-class HeaderToHostHoister(object):
-    """Takes a header and moves it to the front of the hoststring.
-    """
+class HeaderToHostHoister:
+    """Takes a header and moves it to the front of the hoststring."""
+
     _VALID_HOSTNAME = re.compile(r'(?!-)[a-z\d-]{1,63}(?<!-)$', re.IGNORECASE)
 
     def __init__(self, header_name):
@@ -940,10 +968,12 @@ class HeaderToHostHoister(object):
     def _ensure_header_is_valid_host(self, header):
         match = self._VALID_HOSTNAME.match(header)
         if not match:
-            raise ParamValidationError(report=(
-                'Hostnames must contain only - and alphanumeric characters, '
-                'and between 1 and 63 characters long.'
-            ))
+            raise ParamValidationError(
+                report=(
+                    'Hostnames must contain only - and alphanumeric characters, '
+                    'and between 1 and 63 characters long.'
+                )
+            )
 
     def _prepend_to_host(self, url, prefix):
         url_components = urlsplit(url)
@@ -955,7 +985,7 @@ class HeaderToHostHoister(object):
             new_netloc,
             url_components.path,
             url_components.query,
-            ''
+            '',
         )
         new_url = urlunsplit(new_components)
         return new_url
@@ -994,43 +1024,52 @@ def add_retry_headers(request, **kwargs):
 
 BUILTIN_HANDLERS = [
     ('choose-service-name', handle_service_name_alias),
-    ('getattr.mturk.list_hi_ts_for_qualification_type',
-     ClientMethodAlias('list_hits_for_qualification_type')),
-    ('before-parameter-build.s3.UploadPart',
-     convert_body_to_file_like_object, REGISTER_LAST),
-    ('before-parameter-build.s3.PutObject',
-     convert_body_to_file_like_object, REGISTER_LAST),
+    (
+        'getattr.mturk.list_hi_ts_for_qualification_type',
+        ClientMethodAlias('list_hits_for_qualification_type'),
+    ),
+    (
+        'before-parameter-build.s3.UploadPart',
+        convert_body_to_file_like_object,
+        REGISTER_LAST,
+    ),
+    (
+        'before-parameter-build.s3.PutObject',
+        convert_body_to_file_like_object,
+        REGISTER_LAST,
+    ),
     ('creating-client-class', add_generate_presigned_url),
     ('creating-client-class.s3', add_generate_presigned_post),
     ('creating-client-class.iot-data', check_openssl_supports_tls_version_1_2),
     ('creating-client-class.lex-runtime-v2', remove_lex_v2_start_conversation),
     ('after-call.iam', json_decode_policies),
-
     ('after-call.ec2.GetConsoleOutput', decode_console_output),
     ('after-call.cloudformation.GetTemplate', json_decode_template_body),
     ('after-call.s3.GetBucketLocation', parse_get_bucket_location),
-
     ('before-parameter-build', generate_idempotent_uuid),
-
     ('before-parameter-build.s3', validate_bucket_name),
-
-    ('before-parameter-build.s3.ListObjects',
-     set_list_objects_encoding_type_url),
-    ('before-parameter-build.s3.ListObjectsV2',
-     set_list_objects_encoding_type_url),
-    ('before-parameter-build.s3.ListObjectVersions',
-     set_list_objects_encoding_type_url),
-    ('before-parameter-build.s3.CopyObject',
-     handle_copy_source_param),
-    ('before-parameter-build.s3.UploadPartCopy',
-     handle_copy_source_param),
+    (
+        'before-parameter-build.s3.ListObjects',
+        set_list_objects_encoding_type_url,
+    ),
+    (
+        'before-parameter-build.s3.ListObjectsV2',
+        set_list_objects_encoding_type_url,
+    ),
+    (
+        'before-parameter-build.s3.ListObjectVersions',
+        set_list_objects_encoding_type_url,
+    ),
+    ('before-parameter-build.s3.CopyObject', handle_copy_source_param),
+    ('before-parameter-build.s3.UploadPartCopy', handle_copy_source_param),
     ('before-parameter-build.s3.CopyObject', validate_ascii_metadata),
     ('before-parameter-build.s3.PutObject', validate_ascii_metadata),
-    ('before-parameter-build.s3.CreateMultipartUpload',
-     validate_ascii_metadata),
+    (
+        'before-parameter-build.s3.CreateMultipartUpload',
+        validate_ascii_metadata,
+    ),
     ('docs.*.s3.CopyObject.complete-section', document_copy_source_form),
     ('docs.*.s3.UploadPartCopy.complete-section', document_copy_source_form),
-
     ('before-call', add_recursion_detection_header),
     ('before-call.s3', add_expect_header),
     ('before-call.glacier', add_glacier_version),
@@ -1046,13 +1085,18 @@ BUILTIN_HANDLERS = [
     ('request-created.machinelearning.Predict', switch_host_machinelearning),
     ('needs-retry.s3.UploadPartCopy', check_for_200_error, REGISTER_FIRST),
     ('needs-retry.s3.CopyObject', check_for_200_error, REGISTER_FIRST),
-    ('needs-retry.s3.CompleteMultipartUpload', check_for_200_error,
-     REGISTER_FIRST),
+    (
+        'needs-retry.s3.CompleteMultipartUpload',
+        check_for_200_error,
+        REGISTER_FIRST,
+    ),
     ('choose-signer.cognito-identity.GetId', disable_signing),
     ('choose-signer.cognito-identity.GetOpenIdToken', disable_signing),
     ('choose-signer.cognito-identity.UnlinkIdentity', disable_signing),
-    ('choose-signer.cognito-identity.GetCredentialsForIdentity',
-        disable_signing),
+    (
+        'choose-signer.cognito-identity.GetCredentialsForIdentity',
+        disable_signing,
+    ),
     ('choose-signer.sts.AssumeRoleWithSAML', disable_signing),
     ('choose-signer.sts.AssumeRoleWithWebIdentity', disable_signing),
     ('choose-signer', set_operation_specific_signer),
@@ -1066,124 +1110,171 @@ BUILTIN_HANDLERS = [
     ('before-parameter-build.s3.UploadPartCopy', sse_md5),
     ('before-parameter-build.s3.UploadPartCopy', copy_source_sse_md5),
     ('before-parameter-build.ec2.RunInstances', base64_encode_user_data),
-    ('before-parameter-build.autoscaling.CreateLaunchConfiguration',
-     base64_encode_user_data),
+    (
+        'before-parameter-build.autoscaling.CreateLaunchConfiguration',
+        base64_encode_user_data,
+    ),
     ('before-parameter-build.route53', fix_route53_ids),
     ('before-parameter-build.glacier', inject_account_id),
     ('after-call.s3.ListObjects', decode_list_object),
     ('after-call.s3.ListObjectsV2', decode_list_object_v2),
     ('after-call.s3.ListObjectVersions', decode_list_object_versions),
-
     # Cloudsearchdomain search operation will be sent by HTTP POST
-    ('request-created.cloudsearchdomain.Search',
-     change_get_to_post),
+    ('request-created.cloudsearchdomain.Search', change_get_to_post),
     # Glacier documentation customizations
-    ('docs.*.glacier.*.complete-section',
-     AutoPopulatedParam('accountId', 'Note: this parameter is set to "-" by'
-                        'default if no value is not specified.')
-     .document_auto_populated_param),
-    ('docs.*.glacier.UploadArchive.complete-section',
-     AutoPopulatedParam('checksum').document_auto_populated_param),
-    ('docs.*.glacier.UploadMultipartPart.complete-section',
-     AutoPopulatedParam('checksum').document_auto_populated_param),
-    ('docs.request-params.glacier.CompleteMultipartUpload.complete-section',
-     document_glacier_tree_hash_checksum()),
+    (
+        'docs.*.glacier.*.complete-section',
+        AutoPopulatedParam(
+            'accountId',
+            'Note: this parameter is set to "-" by'
+            'default if no value is not specified.',
+        ).document_auto_populated_param,
+    ),
+    (
+        'docs.*.glacier.UploadArchive.complete-section',
+        AutoPopulatedParam('checksum').document_auto_populated_param,
+    ),
+    (
+        'docs.*.glacier.UploadMultipartPart.complete-section',
+        AutoPopulatedParam('checksum').document_auto_populated_param,
+    ),
+    (
+        'docs.request-params.glacier.CompleteMultipartUpload.complete-section',
+        document_glacier_tree_hash_checksum(),
+    ),
     # Cloudformation documentation customizations
-    ('docs.*.cloudformation.GetTemplate.complete-section',
-     document_cloudformation_get_template_return_type),
-
+    (
+        'docs.*.cloudformation.GetTemplate.complete-section',
+        document_cloudformation_get_template_return_type,
+    ),
     # UserData base64 encoding documentation customizations
-    ('docs.*.ec2.RunInstances.complete-section',
-     document_base64_encoding('UserData')),
-    ('docs.*.autoscaling.CreateLaunchConfiguration.complete-section',
-     document_base64_encoding('UserData')),
-
+    (
+        'docs.*.ec2.RunInstances.complete-section',
+        document_base64_encoding('UserData'),
+    ),
+    (
+        'docs.*.autoscaling.CreateLaunchConfiguration.complete-section',
+        document_base64_encoding('UserData'),
+    ),
     # EC2 CopySnapshot documentation customizations
-    ('docs.*.ec2.CopySnapshot.complete-section',
-     AutoPopulatedParam('PresignedUrl').document_auto_populated_param),
-    ('docs.*.ec2.CopySnapshot.complete-section',
-     AutoPopulatedParam('DestinationRegion').document_auto_populated_param),
+    (
+        'docs.*.ec2.CopySnapshot.complete-section',
+        AutoPopulatedParam('PresignedUrl').document_auto_populated_param,
+    ),
+    (
+        'docs.*.ec2.CopySnapshot.complete-section',
+        AutoPopulatedParam('DestinationRegion').document_auto_populated_param,
+    ),
     # S3 SSE documentation modifications
-    ('docs.*.s3.*.complete-section',
-     AutoPopulatedParam('SSECustomerKeyMD5').document_auto_populated_param),
+    (
+        'docs.*.s3.*.complete-section',
+        AutoPopulatedParam('SSECustomerKeyMD5').document_auto_populated_param,
+    ),
     # S3 SSE Copy Source documentation modifications
-    ('docs.*.s3.*.complete-section',
-     AutoPopulatedParam('CopySourceSSECustomerKeyMD5').document_auto_populated_param),
+    (
+        'docs.*.s3.*.complete-section',
+        AutoPopulatedParam(
+            'CopySourceSSECustomerKeyMD5'
+        ).document_auto_populated_param,
+    ),
     # Add base64 information to Lambda
-    ('docs.*.lambda.UpdateFunctionCode.complete-section',
-     document_base64_encoding('ZipFile')),
+    (
+        'docs.*.lambda.UpdateFunctionCode.complete-section',
+        document_base64_encoding('ZipFile'),
+    ),
     # The following S3 operations cannot actually accept a ContentMD5
-    ('docs.*.s3.*.complete-section',
-     HideParamFromOperations(
-         's3', 'ContentMD5',
-         ['DeleteObjects', 'PutBucketAcl', 'PutBucketCors',
-          'PutBucketLifecycle', 'PutBucketLogging', 'PutBucketNotification',
-          'PutBucketPolicy', 'PutBucketReplication', 'PutBucketRequestPayment',
-          'PutBucketTagging', 'PutBucketVersioning', 'PutBucketWebsite',
-          'PutObjectAcl']).hide_param),
-
+    (
+        'docs.*.s3.*.complete-section',
+        HideParamFromOperations(
+            's3',
+            'ContentMD5',
+            [
+                'DeleteObjects',
+                'PutBucketAcl',
+                'PutBucketCors',
+                'PutBucketLifecycle',
+                'PutBucketLogging',
+                'PutBucketNotification',
+                'PutBucketPolicy',
+                'PutBucketReplication',
+                'PutBucketRequestPayment',
+                'PutBucketTagging',
+                'PutBucketVersioning',
+                'PutBucketWebsite',
+                'PutObjectAcl',
+            ],
+        ).hide_param,
+    ),
     #############
     # RDS
     #############
     ('creating-client-class.rds', add_generate_db_auth_token),
-
-    ('before-call.rds.CopyDBClusterSnapshot',
-     inject_presigned_url_rds),
-    ('before-call.rds.CreateDBCluster',
-     inject_presigned_url_rds),
-    ('before-call.rds.CopyDBSnapshot',
-     inject_presigned_url_rds),
-    ('before-call.rds.CreateDBInstanceReadReplica',
-     inject_presigned_url_rds),
-    ('before-call.rds.StartDBInstanceAutomatedBackupsReplication',
-     inject_presigned_url_rds),
-
+    ('before-call.rds.CopyDBClusterSnapshot', inject_presigned_url_rds),
+    ('before-call.rds.CreateDBCluster', inject_presigned_url_rds),
+    ('before-call.rds.CopyDBSnapshot', inject_presigned_url_rds),
+    ('before-call.rds.CreateDBInstanceReadReplica', inject_presigned_url_rds),
+    (
+        'before-call.rds.StartDBInstanceAutomatedBackupsReplication',
+        inject_presigned_url_rds,
+    ),
     # RDS PresignedUrl documentation customizations
-    ('docs.*.rds.CopyDBClusterSnapshot.complete-section',
-     AutoPopulatedParam('PreSignedUrl').document_auto_populated_param),
-    ('docs.*.rds.CreateDBCluster.complete-section',
-     AutoPopulatedParam('PreSignedUrl').document_auto_populated_param),
-    ('docs.*.rds.CopyDBSnapshot.complete-section',
-     AutoPopulatedParam('PreSignedUrl').document_auto_populated_param),
-    ('docs.*.rds.CreateDBInstanceReadReplica.complete-section',
-     AutoPopulatedParam('PreSignedUrl').document_auto_populated_param),
-    ('docs.*.rds.StartDBInstanceAutomatedBackupsReplication.complete-section',
-     AutoPopulatedParam('PreSignedUrl').document_auto_populated_param),
-
+    (
+        'docs.*.rds.CopyDBClusterSnapshot.complete-section',
+        AutoPopulatedParam('PreSignedUrl').document_auto_populated_param,
+    ),
+    (
+        'docs.*.rds.CreateDBCluster.complete-section',
+        AutoPopulatedParam('PreSignedUrl').document_auto_populated_param,
+    ),
+    (
+        'docs.*.rds.CopyDBSnapshot.complete-section',
+        AutoPopulatedParam('PreSignedUrl').document_auto_populated_param,
+    ),
+    (
+        'docs.*.rds.CreateDBInstanceReadReplica.complete-section',
+        AutoPopulatedParam('PreSignedUrl').document_auto_populated_param,
+    ),
+    (
+        'docs.*.rds.StartDBInstanceAutomatedBackupsReplication.complete-section',
+        AutoPopulatedParam('PreSignedUrl').document_auto_populated_param,
+    ),
     #############
     # Neptune
     #############
-    ('before-call.neptune.CopyDBClusterSnapshot',
-     inject_presigned_url_rds),
-    ('before-call.neptune.CreateDBCluster',
-     inject_presigned_url_rds),
-
+    ('before-call.neptune.CopyDBClusterSnapshot', inject_presigned_url_rds),
+    ('before-call.neptune.CreateDBCluster', inject_presigned_url_rds),
     # Neptune PresignedUrl documentation customizations
-    ('docs.*.neptune.CopyDBClusterSnapshot.complete-section',
-     AutoPopulatedParam('PreSignedUrl').document_auto_populated_param),
-    ('docs.*.neptune.CreateDBCluster.complete-section',
-     AutoPopulatedParam('PreSignedUrl').document_auto_populated_param),
-
+    (
+        'docs.*.neptune.CopyDBClusterSnapshot.complete-section',
+        AutoPopulatedParam('PreSignedUrl').document_auto_populated_param,
+    ),
+    (
+        'docs.*.neptune.CreateDBCluster.complete-section',
+        AutoPopulatedParam('PreSignedUrl').document_auto_populated_param,
+    ),
     #############
     # DocDB
     #############
-    ('before-call.docdb.CopyDBClusterSnapshot',
-     inject_presigned_url_rds),
-    ('before-call.docdb.CreateDBCluster',
-     inject_presigned_url_rds),
-
+    ('before-call.docdb.CopyDBClusterSnapshot', inject_presigned_url_rds),
+    ('before-call.docdb.CreateDBCluster', inject_presigned_url_rds),
     # DocDB PresignedUrl documentation customizations
-    ('docs.*.docdb.CopyDBClusterSnapshot.complete-section',
-     AutoPopulatedParam('PreSignedUrl').document_auto_populated_param),
-    ('docs.*.docdb.CreateDBCluster.complete-section',
-     AutoPopulatedParam('PreSignedUrl').document_auto_populated_param),
-
+    (
+        'docs.*.docdb.CopyDBClusterSnapshot.complete-section',
+        AutoPopulatedParam('PreSignedUrl').document_auto_populated_param,
+    ),
+    (
+        'docs.*.docdb.CreateDBCluster.complete-section',
+        AutoPopulatedParam('PreSignedUrl').document_auto_populated_param,
+    ),
     ###########
     # SMS Voice
     ###########
-    ('docs.title.sms-voice',
-     DeprecatedServiceDocumenter('pinpoint-sms-voice').inject_deprecation_notice),
+    (
+        'docs.title.sms-voice',
+        DeprecatedServiceDocumenter(
+            'pinpoint-sms-voice'
+        ).inject_deprecation_notice,
+    ),
     ('before-call', inject_api_version_header_if_needed),
-
 ]
 _add_parameter_aliases(BUILTIN_HANDLERS)
